#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-LUuwg5IQB8CJvdBDaID0Qe
key:                  zlib-bindings-0.1.1.5-LUuwg5IQB8CJvdBDaID0Qe
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  57067ae1237661c75bb8f3d6c04f3954
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-LUuwg5IQB8CJvdBDaID0Qe
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    zlib-0.7.1.0-o5ZrO8tsYqEMdOctKNx4t

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

